window.Gleam.initSearch([{"doc":"glearray","title":"glearray","content":"# glearray\n\n[![Package Version](https://img.shields.io/hexpm/v/glearray)](https://hex.pm/packages/glearray)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glearray/)\n\nA simple library that provides immutable arrays for Gleam.\nCheck out [the docs](https://hexdocs.pm/glearray/glearray.html) for more information.\n\n## Installation\n\nAdd `glearray` to your Gleam project:\n\n```sh\ngleam add glearray\n```\n\n## Targets\n\nThis library supports both the Erlang and JavaScript targets.\n","url":"index.html"},{"doc":"glearray","title":"Array","content":"pub type Array(a)\n Arrays are ordered sequences of elements, similar to lists.\n\n Like everything in Gleam, arrays are immutable.\n As opposed to linked lists, arrays store their elements in a contiguous\n slice of memory, therefore allowing very fast indexed access.\n\n Modifying an array however takes linear time and memory because it requires\n copying the entire array.\n\n ### Implementation\n\n Arrays are represented as tuples when compiled to Erlang, and JavaScript\n arrays when compiled to JavaScript.\n\n Also note that this library has no connection to Erlang&#39;s\n [`array`](https://www.erlang.org/doc/man/array.html) module, which\n implements a tree structure for efficient reading and writing.\n\n\nSynonyms:\nglearray.Array\nglearray Array","url":"glearray.html#Array"},{"doc":"glearray","title":"copy_insert","content":"pub fn copy_insert(\n  into array: Array(a),\n  at index: Int,\n  value value: a,\n) -&gt; Result(Array(a), Nil)\n Inserts an element into the array at the given index.\n\n All following elements are shifted to the right, having their index\n incremented by one.\n\n `Error(Nil)` is returned if the index is less than 0 or greater than\n `length(array)`.\n If the index is equal to `length(array)`, this function behaves like\n [`push`](#push).\n\n ## Performance\n\n This function has to copy the entire array, making it very inefficient\n especially for larger arrays.\n\n ## Examples\n\n \n &gt; from_list([&quot;a&quot;, &quot;b&quot;]) |&gt; copy_insert(0, &quot;c&quot;)\n Ok(from_list([&quot;c&quot;, &quot;a&quot;, &quot;b&quot;]))\n \n\n \n &gt; from_list([&quot;a&quot;, &quot;b&quot;]) |&gt; copy_insert(1, &quot;c&quot;)\n Ok(from_list([&quot;a&quot;, &quot;c&quot;, &quot;b&quot;]))\n \n\n \n &gt; from_list([&quot;a&quot;, &quot;b&quot;]) |&gt; copy_insert(2, &quot;c&quot;)\n Ok(from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]))\n \n\n \n &gt; from_list([&quot;a&quot;, &quot;b&quot;]) |&gt; copy_insert(3, &quot;c&quot;)\n Error(Nil)\n \n\nSynonyms:\nglearray.copy_insert\nglearray copy_insert","url":"glearray.html#copy_insert"},{"doc":"glearray","title":"copy_push","content":"pub fn copy_push(\n  onto array: Array(a),\n  value value: a,\n) -&gt; Array(a)\n Adds a single element to the back of the given array.\n\n ## Performance\n\n This function has to copy the entire array, making it very inefficient\n especially for larger arrays.\n\n ## Examples\n\n \n &gt; new() |&gt; copy_push(1) |&gt; copy_push(2) |&gt; to_list\n [1, 2]\n \n\nSynonyms:\nglearray.copy_push\nglearray copy_push","url":"glearray.html#copy_push"},{"doc":"glearray","title":"copy_set","content":"pub fn copy_set(\n  in array: Array(a),\n  at index: Int,\n  value value: a,\n) -&gt; Result(Array(a), Nil)\n Replaces the element at the given index with `value`.\n\n This function cannot extend an array and returns `Error(Nil)` if `index` is\n not valid.\n See also [`insert`](#insert) and [`push`](#push).\n\n ## Performance\n\n This function has to copy the entire array, making it very inefficient\n especially for larger arrays.\n\n ## Examples\n\n \n &gt; from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]) |&gt; copy_set(1, &quot;x&quot;)\n Ok(from_list([&quot;a&quot;, &quot;x&quot;, &quot;c&quot;]))\n \n\n \n &gt; from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]) |&gt; copy_set(3, &quot;x&quot;)\n Error(Nil)\n \n\nSynonyms:\nglearray.copy_set\nglearray copy_set","url":"glearray.html#copy_set"},{"doc":"glearray","title":"from_list","content":"pub fn from_list(list: List(a)) -&gt; Array(a)\n Converts a list to an array.\n\nSynonyms:\nglearray.from_list\nglearray from_list","url":"glearray.html#from_list"},{"doc":"glearray","title":"get","content":"pub fn get(in array: Array(a), at index: Int) -&gt; Result(a, Nil)\n Returns the element at the specified index, starting from 0.\n\n `Error(Nil)` is returned if `index` is less than 0 or greater than\n or equal to `length(array)`.\n\n ## Performance\n\n This function is very efficient and runs in constant time.\n\n ## Examples\n\n \n &gt; from_list([5, 6, 7]) |&gt; get(1)\n Ok(6)\n \n\n \n &gt; from_list([5, 6, 7]) |&gt; get(3)\n Error(Nil)\n \n\nSynonyms:\nglearray.get\nglearray get","url":"glearray.html#get"},{"doc":"glearray","title":"iterate","content":"pub fn iterate(array: Array(a)) -&gt; Iterator(a)\n Returns an [`Iterator`](https://hexdocs.pm/gleam_stdlib/gleam/iterator.html#Iterator)\n yielding each element in this array.\n\n ## Examples\n\n \n &gt; from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n &gt; |&gt; iterate\n &gt; |&gt; iterator.map(string.uppercase)\n &gt; |&gt; iterator.to_list\n [&quot;A&quot;, &quot;B&quot;, &quot;C&quot;]\n \n\nSynonyms:\nglearray.iterate\nglearray iterate","url":"glearray.html#iterate"},{"doc":"glearray","title":"length","content":"pub fn length(of array: Array(a)) -&gt; Int\n Returns the number of elements in the array.\n\n ## Performance\n\n This function is very efficient and runs in constant time.\n\n ## Examples\n\n \n &gt; length(new())\n 0\n \n\n \n &gt; from_list([8, 0, 0]) |&gt; length\n 3\n \n\nSynonyms:\nglearray.length\nglearray length","url":"glearray.html#length"},{"doc":"glearray","title":"new","content":"pub fn new() -&gt; Array(a)\n Returns an empty array.\n\n ## Examples\n\n \n &gt; new()\n from_list([])\n \n\nSynonyms:\nglearray.new\nglearray new","url":"glearray.html#new"},{"doc":"glearray","title":"to_list","content":"pub fn to_list(array: Array(a)) -&gt; List(a)\n Converts an array to a list.\n\nSynonyms:\nglearray.to_list\nglearray to_list","url":"glearray.html#to_list"},{"doc":"glearray","title":"glearray","content":"","url":"glearray.html"}]);